@@ -545,6 +545,7 @@ class LGEOS300(LGEOSBase):
                 self.GEOSisValid,
                 self.GEOSisSimple,
                 self.GEOSisRing,
+                self.GEOSisClosed,
                 self.GEOSHasZ):
             pred.errcheck = errcheck_predicate
 
@@ -560,6 +561,7 @@ class LGEOS300(LGEOSBase):
         self.methods['has_z'] = self.GEOSHasZ
         self.methods['is_empty'] = self.GEOSisEmpty
         self.methods['is_ring'] = self.GEOSisRing
+        self.methods['is_closed'] = self.GEOSisClosed
         self.methods['is_simple'] = self.GEOSisSimple
         self.methods['is_valid'] = self.GEOSisValid
         self.methods['disjoint'] = self.GEOSDisjoint
@@ -620,6 +622,7 @@ class LGEOS310(LGEOSBase):
                 self.GEOSisValid,
                 self.GEOSisSimple,
                 self.GEOSisRing,
+                self.GEOSisClosed,
                 self.GEOSHasZ):
             pred.func.errcheck = errcheck_predicate
 
@@ -637,6 +640,7 @@ class LGEOS310(LGEOSBase):
         self.methods['has_z'] = self.GEOSHasZ
         self.methods['is_empty'] = self.GEOSisEmpty
         self.methods['is_ring'] = self.GEOSisRing
+        self.methods['is_closed'] = self.GEOSisClosed
         self.methods['is_simple'] = self.GEOSisSimple
         self.methods['is_valid'] = self.GEOSisValid
         self.methods['disjoint'] = self.GEOSDisjoint
@@ -713,7 +717,21 @@ class LGEOS330(LGEOS320):
         self.methods['cascaded_union'] = self.methods['unary_union']
 
 
-if geos_version >= (3, 3, 0):
+class LGEOS340(LGEOS330):
+    """Proxy for GEOS 3.4.0-CAPI-1.8.0
+    """
+    geos_version = (3, 4, 0)
+    geos_capi_version = (1, 8, 0)
+
+    def __init__(self, dll):
+        super(LGEOS340, self).__init__(dll)
+        self.methods['delaunay_triangulation'] = self.GEOSDelaunayTriangulation
+        self.methods['nearest_points'] = self.GEOSNearestPoints
+
+
+if geos_version >= (3, 4, 0):
+    L = LGEOS340
+elif geos_version >= (3, 3, 0):
     L = LGEOS330
 elif geos_version >= (3, 2, 0):
     L = LGEOS320
