@@ -11,7 +11,7 @@ This is layer number 2 from the list below.
 Shapely 1.2 includes a GEOS backend and it is the default.
 """
 
-from ftools import wraps
+from .ftools import wraps
 
 from shapely.algorithms import cga
 from shapely.coords import BoundsOp
@@ -29,8 +29,8 @@ def delegated(func):
         try:
             return func(*args, **kwargs)
         except KeyError:
-            raise AttributeError, "Method '%s' is not supported by %s" % (
-                func.__name__, repr(args[0].impl))
+            raise AttributeError("Method %r is not supported by %r" %
+                                 (func.__name__, args[0].impl))
     return wrapper
 
 # Map geometry methods to their GEOS delegates
@@ -50,7 +50,7 @@ class GEOSImpl(BaseImpl):
         return '<GEOSImpl object: GEOS C API version %s>' % (
             lgeos.geos_capi_version,)
 
-IMPL14 = {
+IMPL300 = {
     'area': (UnaryRealProperty, 'area'),
     'distance': (BinaryRealProperty, 'distance'),
     'length': (UnaryRealProperty, 'length'),
@@ -71,6 +71,7 @@ IMPL14 = {
     'has_z': (UnaryPredicate, 'has_z'),
     'is_empty': (UnaryPredicate, 'is_empty'),
     'is_ring': (UnaryPredicate, 'is_ring'),
+    'is_closed': (UnaryPredicate, 'is_closed'),
     'is_simple': (UnaryPredicate, 'is_simple'),
     'is_valid': (UnaryPredicate, 'is_valid'),
     #
@@ -89,7 +90,7 @@ IMPL14 = {
     'is_ccw': (cga.is_ccw_impl, 'is_ccw'),
     }
 
-IMPL15 = {
+IMPL310 = {
     'simplify': (UnaryTopologicalOp, 'simplify'),
     'topology_preserve_simplify':
         (UnaryTopologicalOp, 'topology_preserve_simplify'),
@@ -100,27 +101,27 @@ IMPL15 = {
     'prepared_covers': (BinaryPredicate, 'prepared_covers'),
     }
 
-IMPL16 = {
-    'buffer_with_style': (UnaryTopologicalOp, 'buffer_with_style'),
+IMPL311 = {
     }
 
-IMPL16LR = {
-	'parallel_offset': (UnaryTopologicalOp, 'parallel_offset'),
-	'project_normalized': (ProjectOp, 'project_normalized'),
+IMPL320 = {
+    'parallel_offset': (UnaryTopologicalOp, 'parallel_offset'),
+    'project_normalized': (ProjectOp, 'project_normalized'),
     'project': (ProjectOp, 'project'),
     'interpolate_normalized': (InterpolateOp, 'interpolate_normalized'),
     'interpolate': (InterpolateOp, 'interpolate'),
+    'buffer_with_style': (UnaryTopologicalOp, 'buffer_with_style'),
     }
 
 def impl_items(defs):
-    return [(k, v[0](v[1])) for k, v in defs.items()]
+    return [(k, v[0](v[1])) for k, v in list(defs.items())]
 
-imp = GEOSImpl(dict(impl_items(IMPL14)))
-if lgeos.geos_capi_version >= (1, 5, 0):
-    imp.update(impl_items(IMPL15))
-if lgeos.geos_capi_version >= (1, 6, 0):
-    imp.update(impl_items(IMPL16))
-    if 'project' in lgeos.methods:
-        imp.update(impl_items(IMPL16LR))
+imp = GEOSImpl(dict(impl_items(IMPL300)))
+if lgeos.geos_version >= (3, 1, 0):
+    imp.update(impl_items(IMPL310))
+if lgeos.geos_version >= (3, 1, 1):
+    imp.update(impl_items(IMPL311))
+if lgeos.geos_version >= (3, 2, 0):
+    imp.update(impl_items(IMPL320))
 
 DefaultImplementation = imp
